==> 1.1.1.tar.gz: doc/AppleApi.md <==
# forestvpn_api.api.AppleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**verifyReceipt**](AppleApi.md#verifyReceipt) | **POST** /apple/verify-receipt/ | Verify receipt


# **verifyReceipt**
> verifyReceipt(request)

Verify receipt

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = AppleApi();
var request = AppleVerifyReceiptRequest(); // AppleVerifyReceiptRequest | 

try { 
    api_instance.verifyReceipt(request);
} catch (e) {
    print("Exception when calling AppleApi->verifyReceipt: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**AppleVerifyReceiptRequest**](AppleVerifyReceiptRequest.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.2.4.tar.gz: doc/AppleApi.md <==
# forestvpn_api.api.AppleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**verifyReceipt**](AppleApi.md#verifyreceipt) | **POST** /apple/verify-receipt/ | Verify receipt


# **verifyReceipt**
> verifyReceipt(request)

Verify receipt

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AppleApi();
final request = AppleVerifyReceiptRequest(); // AppleVerifyReceiptRequest | 

try { 
    api_instance.verifyReceipt(request);
} catch (e) {
    print('Exception when calling AppleApi->verifyReceipt: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**AppleVerifyReceiptRequest**](AppleVerifyReceiptRequest.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
